@@ -1,6 +1,11 @@
 import { Component } from "@angular/core"
-import { BalloonMsgService, NgLifeCycleEvents } from "@synerty/peek-plugin-base-js"
-import { extend, TupleLoader, VortexService } from "@synerty/vortexjs"
+import { BalloonMsgService } from "@synerty/peek-plugin-base-js"
+import {
+    extend,
+    NgLifeCycleEvents,
+    TupleLoader,
+    VortexService
+} from "@synerty/vortexjs"
 import { docDbFilt, SettingPropertyTuple } from "@peek/peek_core_docdb/_private"
 
 @Component({
