@@ -1,6 +1,10 @@
 import { Component } from "@angular/core"
-import { BalloonMsgService, NgLifeCycleEvents } from "@synerty/peek-plugin-base-js"
-import { TupleDataObserverService, TupleSelector } from "@synerty/vortexjs"
+import { BalloonMsgService } from "@synerty/peek-plugin-base-js"
+import {
+    NgLifeCycleEvents,
+    TupleDataObserverService,
+    TupleSelector
+} from "@synerty/vortexjs"
 import { AdminStatusTuple } from "@peek/peek_core_docdb/_private"
 
 @Component({
