@@ -1,7 +1,8 @@
 import { Injectable } from "@angular/core"
-import { NgLifeCycleEvents } from "@synerty/peek-plugin-base-js"
 import {
     extend,
+    Jsonable,
+    NgLifeCycleEvents,
     Payload,
     PayloadEnvelope,
     TupleOfflineStorageNameService,
@@ -12,10 +13,13 @@ import {
     VortexStatusService
 } from "@synerty/vortexjs"
 
-import { docDbCacheStorageName, docDbFilt, docDbTuplePrefix } from "../PluginNames"
+import {
+    docDbCacheStorageName,
+    docDbFilt,
+    docDbTuplePrefix
+} from "../PluginNames"
 
-import { Subject } from "rxjs"
-import { Observable } from "rxjs"
+import { Observable, Subject } from "rxjs"
 import { EncodedDocumentChunkTuple } from "./EncodedDocumentChunkTuple"
 import { DocumentUpdateDateTuple } from "./DocumentUpdateDateTuple"
 import { DocumentTuple } from "../../DocumentTuple"
@@ -576,6 +580,7 @@ export class PrivateDocumentLoaderService extends NgLifeCycleEvents {
                             
                             // Reconstruct the data
                             let objectProps: {} = JSON.parse(chunkData[key])
+                            objectProps = new Jsonable().fromJsonField(objectProps)
                             
                             // Get out the object type
                             let thisDocumentTypeId = objectProps["_dtid"]
